@@ -1,5 +1,5 @@
 // Copyright (c) 1995  David Engberg  All rights reserved
-// $Id: Expression.h,v 1.11 1996/08/03 03:03:01 geppetto Exp $
+// $Id: Expression.h,v 1.12 1997/03/02 22:53:43 geppetto Exp $
 #ifndef _Expression_h
 #define _Expression_h
 #pragma interface
@@ -275,6 +275,9 @@ protected:
   virtual CCompileError* HandleEvaluateType(CCompileContext& context,
 					    CJavaTypeSignature& setType);
 private:
+  bool UnifyNumeric(CExpression*& first, CExpression*& second,
+		    CCompileContext& context, CJavaTypeSignature& setType);
+
   CExpression* fLeft;
   CExpression* fMiddle;
   CExpression* fRight;
@@ -366,6 +369,7 @@ public:
   
   bool IsStatic() const;
   bool IsArrayLength() const;
+  unicode_string GetFieldString() const { return fLabel; }
 
   virtual CCompileError* CreateConstantExpression(CExpression*& result,
 			  CCompileContext& context) const;
